
.. _algorithms/isomorphism:

Isomorphism
***********

Algorithms
----------

.. automodule:: jgrapht.algorithms.isomorphism
   :members:


Types
-----

A mapping from one graph to another is represented using instances of the following class.

.. autoclass:: jgrapht.types.GraphMapping
   :members:

